* OBJECTIVE: Robustness Checks of Progresa_Regressions for Doepke-Tertilt. Specifically I check whether
* the inclusion of durables, livestock, housing investments in our expenditure measure drives the results of 
* log expenditure or the implicit savings share.

clear

set mem 1000m
set more off

capture log close
log using DT_Robustness.log, replace


************
* Settings *
************

* Define Directories
local cddir   = "/Users/titanalon/Documents/RA/Doepke/Progresa Project/"
local datadir = "/Users/titanalon/Documents/RA/Doepke/Progresa Project/Processed Data Sets/" //Where should cleaned data be saved?

cd "`cddir'"

use "`datadir'Progresa_Regressions_Data.dta", clear // read in data (see Progresa_Regressions_Data.do for details)


********************
* Create Variables *
********************

* Fille in missing eligibility\treatment data with 1997 characteristic files when possible
replace elig  = elig97  if elig ==.
replace treat = treat97 if treat==.

* Transfers Data -- see transfer processing do file for more details 
gen progresa_pay  = transf_avg
replace progresa_pay  = 0 if treat==0 //replace missing progresa payments with zero for those not treated
replace progresa_pay  = 0 if elig ==0 & progresa_pay == . // replace missing progresa payments with zero for those ineligible

* Robust Expenditure Measures
gen expenditure3 = expenditure2 - livestock // can only use two waves
gen expenditure4 = expenditure2 - livestock - durables - fixhouse // can only use wave 1

* Expenditures Variables
gen logexp     =log(expenditure2)
gen logexp3    =log(expenditure3)
gen logexp4    =log(expenditure4) 

* Income Variables
qui replace income  =income+progresa_pay+fsup+msup+kidsup
qui replace fincome =fincome+progresa_pay+fsup
qui replace mincome =mincome+msup

gen logincome  =log(income)
gen logincome2 =log(income)^2

* Female Income Share
gen finsh = fincome/income

* Implied Savings
gen sav_share     = (income-expenditure2)/income
gen sav_share3    = (income-expenditure3)/income 
gen sav_share4    = (income-expenditure4)/income 


* Survey Dummies
replace dum99n = 0 if dum99n==.
replace dum99m = 0 if dum99m==.

**********************
*** Summary States ***
**********************

* 2(b) By Survey Wave
qui gen wave="."
qui replace wave = "98 Oct" if tdum==1
qui replace wave = "99 Mar" if tdum==2
qui replace wave = "99 Nov" if tdum==3

* NOTE: These are summary stats BEFORE the data is winsorized -- see below
tabstat expenditure2 expenditure3 expenditure4 logexp logexp3 logexp4 sav_share sav_share3 sav_share4 livestock fixhouse durables, by(wave) stat(N mean sd IQR) col(stat) nototal long

* Number of Zeros for Each
gen livestock_zero = .
replace livestock_zero = 1 if livestock == 0
replace livestock_zero = 0 if livestock >0 & livestock~=.

gen durables_zero  = .
replace durables_zero  = 1 if durables  == 0
replace durables_zero  = 0 if  durables >0 & durables~=.


gen fixhouse_zero  = .
replace fixhouse_zero  = 1 if fixhouse  == 0
replace fixhouse_zero  = 0 if fixhouse >0 & fixhouse~=.

qui label define labs 0 "> 0 " 1 "= 0"
qui label values livestock_zero labs
qui label values durables_zero labs
qui label values fixhouse_zero labs

tab livestock_zero wave, col
tab durables_zero wave, col
tab fixhouse_zero wave, col


* NOTES:
* Expenditure 3 subtracts off net livestock investment and uses data from all three waves
* Expenditure 4 subtracts off net livestock, durables, and housing expenditures, but this can only be done for first wave

**********************
*** Winsorize Data ***
**********************

* This is done below before each set of regressions seperately.

***************
* REGRESSIONS *
***************

tempfile maindat
save `maindat'

* Expenditure cleaning out net livestock investment (expenditure3)
* Set 3: Full Controls, OLS - RHS includes inc, inc^2, and female income share
keep if expenditure3>0 & expenditure3~=.
drop if sav_share3<-5 | sav_share3>1

foreach var of varlist logexp3 sav_share3 {
	reg `var' finsh logincome logincome2 hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage   ,  robust  cluster(folio)	
}
*

* Set 4: Full Controls, IV  - RHS includes inc, inc^2, and female income share
foreach var of varlist logexp3 sav_share3 {
	ivreg `var' (finsh = progresa_pay) logincome logincome2 hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage   ,  robust  cluster(folio)	
}
*

* Expenditure cleaning out net livestock, durables, and housing expenditures (expenditure4)
use `maindat', clear
keep if expenditure4>0 & expenditure4~=.
drop if sav_share4<-5 | sav_share4>1

* Set 3: Full Controls, OLS - RHS includes inc, inc^2, and female income share
foreach var of varlist logexp4 sav_share4 {
	reg `var' finsh logincome logincome2 hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage   ,  robust  cluster(folio)	
}
*

* Set 4: Full Controls, IV  - RHS includes inc, inc^2, and female income share
foreach var of varlist logexp4 sav_share4 {
	ivreg `var' (finsh = progresa_pay) logincome logincome2 hh_size nkids_school nkids_prim nfkids elig feduc meduc mage fage   ,  robust  cluster(folio)	
}
*
